@@ -11,6 +11,7 @@ INSTALLED_APPS = [
     "magicauth",
     "django_otp",
     "django_otp.plugins.otp_static",
+    "django.contrib.sites",
 ]
 
 SESSION_ENGINE = "django.contrib.sessions.backends.cache"
@@ -30,3 +31,5 @@ MIDDLEWARE = [
     "django.contrib.sites.middleware.CurrentSiteMiddleware",
     "django_otp.middleware.OTPMiddleware",
 ]
+
+SITE_ID = 1
